@@ -39,7 +39,7 @@ class ConfusionMatrix():
             matrix=None,
             digit=5, threshold=None, file=None,
             sample_weight=None, transpose=False,
-            classes=None):
+            classes=None, is_imbalanced=None):
         """
         Init method.
 
@@ -61,12 +61,15 @@ class ConfusionMatrix():
         :type transpose : bool
         :param classes: ordered labels of classes
         :type classes: list
+        :param is_imbalanced: imbalance dataset flag
+        :type is_imbalanced: bool
         """
         self.actual_vector = actual_vector
         self.predict_vector = predict_vector
         self.digit = digit
         self.weights = None
         self.classes = None
+        self.imbalance = None
         if isinstance(transpose, bool):
             self.transpose = transpose
         else:
@@ -83,9 +86,13 @@ class ConfusionMatrix():
         __obj_assign_handler__(self, matrix_param)
         __class_stat_init__(self)
         __overall_stat_init__(self)
-        self.imbalance = imbalance_check(self.P)
+        if self.imbalance is None:
+            if is_imbalanced is None:
+                is_imbalanced = imbalance_check(self.P)
+            self.imbalance = is_imbalanced
         self.binary = binary_check(self.classes)
-        self.recommended_list = statistic_recommend(self.classes, self.P)
+        self.recommended_list = statistic_recommend(
+            self.classes, self.imbalance)
         self.sparse_matrix = None
         self.sparse_normalized_matrix = None
         self.positions = None
@@ -467,7 +474,8 @@ class ConfusionMatrix():
                          "Matrix": matrix_items,
                          "Digit": self.digit,
                          "Sample-Weight": weights_vector_temp,
-                         "Transpose": self.transpose}
+                         "Transpose": self.transpose,
+                         "Imbalanced": self.imbalance}
             if save_stat:
                 dump_dict["Class-Stat"] = self.class_stat
                 dump_dict["Overall-Stat"] = self.overall_stat
