@@ -372,12 +372,17 @@ def classes_filter(actual_vector, predict_vector, classes=None):
             return [actual_vector, predict_vector, classes]
         classes, _ = vector_filter(classes, [])
         classes_from_vectors = classes_list
-        if isinstance(actual_vector[0], str) and not isinstance(classes[0], str):
+        if isinstance(
+                actual_vector[0],
+                str) and not isinstance(
+                classes[0],
+                str):
             classes = list(map(str, classes))
         elif isinstance(classes[0], str) and not isinstance(actual_vector[0], str):
             actual_vector = list(map(str, actual_vector))
             predict_vector = list(map(str, predict_vector))
-            classes_from_vectors = set(actual_vector).union(set(predict_vector))
+            classes_from_vectors = set(
+                actual_vector).union(set(predict_vector))
         if not set(classes).issubset(classes_from_vectors):
             warn(CLASSES_WARNING, RuntimeWarning)
         classes_list = classes
@@ -436,17 +441,17 @@ def complement(input_number):
         return "None"
 
 
-def statistic_recommend(classes, P):
+def statistic_recommend(classes, imbalance):
     """
     Return recommend parameters which are more suitable due to the input dataset characteristics.
 
     :param classes:  all classes name
     :type classes : list
-    :param P: condition positive
-    :type P : dict
+    :param imbalance : imbalance flag
+    :type imbalance : bool
     :return: recommendation_list as list
     """
-    if imbalance_check(P):
+    if imbalance:
         return IMBALANCED_RECOMMEND
     if binary_check(classes):
         return BINARY_RECOMMEND
